==> sigutils-2.4.6.tar.gz: sigutils-2.4.6/SigUtils/sigmail.py <==
__Autor__ = "Luiz Fernando"
__Empresa__ = "Sig Informatica Ltda"
__Site__ = "http://www.siginformatica.com.br"
__Versao__ = "1.05"
__DataAlteracao__ = "29/04/2009"

import sys
import base64
from StringIO import StringIO


def enviaEmail(smtpServer, de, senha, para, assunto, texto, anexo=None, smtpPort=25, _cc=None, _cco=None):
    def attachText(_writer, _text,_mime):
        part = _writer.nextpart()
        body = part.startbody(_mime)
        body.write(_text)
    def attachPlainFile(_writer, _file, _mimeType=None,
                        _name="unknown"):
        part = _writer.nextpart()
        part.addheader('Content-Transfer-Encoding','base64')
        body = part.startbody("%s; name=%s"%(_mimeType,_name))
        base64.encode(open(_name, 'rb'),body)
    from smtplib import SMTP
    from smtplib import SMTPException
    from socket import sslerror
    import MimeWriter
    import mimetypes
    mensagem = StringIO()
    writer = MimeWriter.MimeWriter(mensagem)
    writer.addheader('MIME-Version', '1.0')
    writer.addheader('Subject', assunto)
    writer.addheader('To',para)
    para=[para]
    if _cc:
        writer.addheader('Cc',_cc)
        para.append(_cc)
    if _cco:
        writer.addheader('Cco',_cco)
        para.append(_cco)
    writer.startmultipartbody('mixed')
    
    if anexo:
         attachText(writer,texto,'text/plain')
         attachPlainFile(writer, texto, 'EncryptedContent.ENCRYPTED', anexo)
    else:
         attachText(writer,texto,'text/plain')
    writer.lastpart()
    try:
        server = SMTP(smtpServer, smtpPort)
        server.ehlo(de)
        server.starttls()
        server.ehlo(de)  # say hello again
        server.login(de, senha)
        server.sendmail(de, para, mensagem.getvalue())
        server.quit()
    except SMTPException:
        sys.exit(2)

if __name__ == '__main__':
   if sys.argv[1] == '-v':
      print
      print("sigmail - Envio de emails")
      print("Versao: " + __Versao__ + ' de: ' + __DataAlteracao__)
      print("Empresa: " + __Empresa__ )
      print( __Site__ )
      print
      sys.exit()
   if sys.argv[1] == '-9':
      print('sigmail.py\t\tVersao:' + __Versao__ + '\tData:'+ __DataAlteracao__) + '\tEnvio de emails'
      sys.exit()
   print (sys.argv)
   p1=sys.argv[1]
   p2=sys.argv[2]
   p3=sys.argv[3]
   p4=sys.argv[4]
   p5=sys.argv[5]
   p6=sys.argv[6]
   p7=sys.argv[7]
   p8=sys.argv[8]
   try:
       p9=sys.argv[9]
   except:
       p9=''
   try:
       p10=sys.argv[10]
   except:
       p10=''
   enviaEmail(p1, p2, p3, p4, p5, p6, p7, p8, p9, p10)
   #enviaEmail('smtp.gmail.com', 'luiz@siginformatica.com.br', 'sig123', 'siginfo@terra.com.br', 
   #  'teste de mensagem sigmail', 'teste de mensagem de emails ', '/mm/arquivos/luiz.htm', 587, p9, p10)

==> sigutils-3.1.5.tar.gz: sigutils-3.1.5/SigUtils/sigmail.py <==
__Autor__ = "Luiz Fernando"
__Empresa__ = "Sig Informatica Ltda"
__Site__ = "http://www.siginformatica.com.br"
__Versao__ = "1.05"
__DataAlteracao__ = "29/04/2009"

import sys
import base64
from io import StringIO


def enviaEmail(smtpServer, de, senha, para, assunto, texto, anexo=None, smtpPort=25, _cc=None, _cco=None):
    def attachText(_writer, _text,_mime):
        part = _writer.nextpart()
        body = part.startbody(_mime)
        body.write(_text)
    def attachPlainFile(_writer, _file, _mimeType=None,
                        _name="unknown"):
        part = _writer.nextpart()
        part.addheader('Content-Transfer-Encoding','base64')
        body = part.startbody("%s; name=%s"%(_mimeType,_name))
        base64.encode(open(_name, 'rb'),body)
    from smtplib import SMTP
    from smtplib import SMTPException
    from email.message import EmailMessage
    import mimetypes
    mensagem = StringIO()
    writer = EmailMessage()
    writer.add_header('MIME-Version', '1.0')
    writer.add_header('Subject', assunto)
    writer.add_header('To',para)
    para=[para]
    if _cc:
        writer.add_header('Cc',_cc)
        para.append(_cc)
    if _cco:
        writer.add_header('Cco',_cco)
        para.append(_cco)
    writer.startmultipartbody('mixed')
    
    if anexo:
         attachText(writer,texto,'text/plain')
         attachPlainFile(writer, texto, 'EncryptedContent.ENCRYPTED', anexo)
    else:
         attachText(writer,texto,'text/plain')
    writer.lastpart()
    try:
        server = SMTP(smtpServer, smtpPort)
        server.ehlo(de)
        server.starttls()
        server.ehlo(de)  # say hello again
        server.login(de, senha)
        server.sendmail(de, para, mensagem.getvalue())
        server.quit()
    except SMTPException:
        sys.exit(2)

if __name__ == '__main__':
   if sys.argv[1] == '-v':
    print()
    print("sigmail - Envio de emails")
    print("Versao: " + __Versao__ + ' de: ' + __DataAlteracao__)
    print("Empresa: " + __Empresa__ )
    print( __Site__ )
    print()
    sys.exit()
   if sys.argv[1] == '-9':
      print(('sigmail.py\t\tVersao:' + __Versao__ + '\tData:'+ __DataAlteracao__) + '\tEnvio de emails')
      sys.exit()
   print(sys.argv)
   p1=sys.argv[1]
   p2=sys.argv[2]
   p3=sys.argv[3]
   p4=sys.argv[4]
   p5=sys.argv[5]
   p6=sys.argv[6]
   p7=sys.argv[7]
   p8=sys.argv[8]
   try:
       p9=sys.argv[9]
   except:
       p9=''
   try:
       p10=sys.argv[10]
   except:
       p10=''
   enviaEmail(p1, p2, p3, p4, p5, p6, p7, p8, p9, p10)
   #enviaEmail('smtp.gmail.com', 'luiz@siginformatica.com.br', 'sig123', 'siginfo@terra.com.br', 
   #  'teste de mensagem sigmail', 'teste de mensagem de emails ', '/mm/arquivos/luiz.htm', 587, p9, p10)
